@@ -4,10 +4,9 @@ Validation errors, and some surrounding helpers.
 from __future__ import annotations
 
 from collections import defaultdict, deque
-from collections.abc import Iterable, Mapping, MutableMapping
 from pprint import pformat
 from textwrap import dedent, indent
-from typing import ClassVar
+from typing import TYPE_CHECKING, ClassVar
 import heapq
 import itertools
 import warnings
@@ -17,6 +16,9 @@ from referencing.exceptions import Unresolvable as _Unresolvable
 
 from jsonschema import _utils
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable, Mapping, MutableMapping
+
 WEAK_MATCHES: frozenset[str] = frozenset(["anyOf", "oneOf"])
 STRONG_MATCHES: frozenset[str] = frozenset()
 
@@ -159,7 +161,7 @@ class _Error(Exception):
             "message", "cause", "context", "validator", "validator_value",
             "path", "schema_path", "instance", "schema", "parent",
         )
-        return dict((attr, getattr(self, attr)) for attr in attrs)
+        return {attr: getattr(self, attr) for attr in attrs}
 
     def _matches_type(self):
         try:
@@ -462,7 +464,7 @@ def best_match(errors, key=relevance):
         # Calculate the minimum via nsmallest, because we don't recurse if
         # all nested errors have the same relevance (i.e. if min == max == all)
         smallest = heapq.nsmallest(2, best.context, key=key)
-        if len(smallest) == 2 and key(smallest[0]) == key(smallest[1]):
+        if len(smallest) == 2 and key(smallest[0]) == key(smallest[1]):  # noqa: PLR2004
             return best
         best = smallest[0]
     return best
